@@ -38,7 +38,7 @@ pub type CompilationResult<T> = Result<T, CompilationError>;
 /// Execution will begin with the first Lane
 pub(crate) type LaneSlice<'a> = &'a [LaneIr];
 pub(crate) type NameSpace = smallvec::SmallVec<[Box<str>; 8]>;
-pub(crate) type Imports = std::collections::HashMap<String, String>;
+pub(crate) type ImportsIr = std::collections::HashMap<String, String>;
 
 pub struct Compiler<'a> {
     options: CompileOptions,
@@ -49,7 +49,7 @@ pub struct Compiler<'a> {
     jump_table: CaoHashMap<String, LaneMeta>,
 
     current_namespace: Cow<'a, NameSpace>,
-    current_imports: Cow<'a, Imports>,
+    current_imports: Cow<'a, ImportsIr>,
     locals: Box<arrayvec::ArrayVec<Local<'a>, 255>>,
     scope_depth: i32,
     current_index: CardIndex,
@@ -239,6 +239,10 @@ impl<'a> Compiler<'a> {
     /// return its index
     fn add_local(&mut self, name: &'a str) -> CompilationResult<u32> {
         self.validate_var_name(name)?;
+        self.add_local_unchecked(name)
+    }
+
+    fn add_local_unchecked(&mut self, name: &'a str) -> CompilationResult<u32> {
         let result = self.locals.len();
         self.locals
             .try_push(Local {
@@ -426,66 +430,123 @@ impl<'a> Compiler<'a> {
                     self.current_index.pop_subindex()
                 }
             }
-            Card::ForEach { variable, lane } => {
-                let arity = match self.jump_table.get(&lane.0) {
-                    Some(x) => x.arity,
-                    None => {
-                        return Err(self.error(CompilationErrorPayload::InvalidJump {
-                            dst: lane.clone(),
-                            msg: Some("ForEach target lane not found".to_string()),
-                        }))
-                    }
+            Card::ForEach {
+                i,
+                k,
+                o,
+                variable,
+                body,
+            } => {
+                self.current_index.push_subindex(0);
+                self.process_card(variable)?;
+                self.current_index.pop_subindex();
+
+                self.scope_begin();
+                let loop_var = self.add_local_unchecked("")?;
+                let loop_item = self.add_local_unchecked("")?;
+                // ForEach instruction will push these values on the stack
+                let o = match o {
+                    Some(o) => self.add_local(&o.0)?,
+                    None => self.add_local_unchecked("")?,
+                };
+                let k = match k {
+                    Some(k) => self.add_local(&k.0)?,
+                    None => self.add_local_unchecked("")?,
+                };
+                let i = match i {
+                    Some(i) => self.add_local(&i.0)?,
+                    None => self.add_local_unchecked("")?,
                 };
-                if arity != 2 {
-                    return Err(self.error(CompilationErrorPayload::InvalidJump {
-                        dst: lane.clone(),
-                        msg: Some("ForEach lanes need to have 2 parameters".to_string()),
-                    }));
-                }
-                self.read_var_card(variable)?;
                 self.push_instruction(Instruction::BeginForEach);
+                write_to_vec(loop_var, &mut self.program.bytecode);
+                write_to_vec(loop_item, &mut self.program.bytecode);
+
                 let block_begin = self.program.bytecode.len() as i32;
                 self.push_instruction(Instruction::ForEach);
-                self.encode_jump(lane)?;
-                // return to the repeat instruction
-                self.push_instruction(Instruction::GotoIfTrue);
-                write_to_vec(block_begin, &mut self.program.bytecode);
+                write_to_vec(loop_var, &mut self.program.bytecode);
+                write_to_vec(loop_item, &mut self.program.bytecode);
+                write_to_vec(i, &mut self.program.bytecode);
+                write_to_vec(k, &mut self.program.bytecode);
+                write_to_vec(o, &mut self.program.bytecode);
+                self.encode_if_then(Instruction::GotoIfFalse, |c| {
+                    c.current_index.push_subindex(1);
+                    c.process_card(body)?;
+                    c.current_index.pop_subindex();
+                    // return to the foreach instruction
+                    c.push_instruction(Instruction::Goto);
+                    write_to_vec(block_begin, &mut c.program.bytecode);
+                    Ok(())
+                })?;
+                self.scope_end();
             }
-            // TODO: blocked by lane ABI
-            Card::While(_) => {
-                return Err(self.error(CompilationErrorPayload::Unimplemented("While cards")))
-            }
-            Card::Repeat(repeat) => {
-                let arity = match self.jump_table.get(&repeat.0) {
-                    Some(x) => x.arity,
-                    None => {
-                        return Err(self.error(CompilationErrorPayload::InvalidJump {
-                            dst: repeat.clone(),
-                            msg: Some("ForEach target lane not found".to_string()),
-                        }))
-                    }
-                };
-                if arity != 1 {
-                    return Err(self.error(CompilationErrorPayload::InvalidJump {
-                        dst: repeat.clone(),
-                        msg: Some("Repeat lanes need to have 1 parameter".to_string()),
-                    }));
-                }
-                self.push_instruction(Instruction::BeginRepeat);
+            Card::While { condition, body } => {
                 let block_begin = self.program.bytecode.len() as i32;
-                self.push_instruction(Instruction::Repeat);
-                self.encode_jump(repeat)?;
-                // return to the repeat instruction
-                self.push_instruction(Instruction::GotoIfTrue);
-                write_to_vec(block_begin, &mut self.program.bytecode);
+                self.current_index.push_subindex(0);
+                self.process_card(condition)?;
+                self.current_index.pop_subindex();
+                self.current_index.push_subindex(1);
+                // if false jump over the body block
+                self.encode_if_then(Instruction::GotoIfFalse, |c| {
+                    // if true execute body and jump to block_begin
+                    c.process_card(body)?;
+                    c.push_instruction(Instruction::Goto);
+                    write_to_vec(block_begin, &mut c.program.bytecode);
+                    Ok(())
+                })?;
+                self.current_index.pop_subindex();
+            }
+            Card::Repeat { i, body: repeat } => {
+                self.scope_begin();
+                let loop_n_index = self.add_local_unchecked("")?;
+                let loop_counter_index = self.add_local_unchecked("")?;
+                let i_index = match i {
+                    Some(var) => {
+                        let index = self.add_local(&var.0)?;
+                        Some(index)
+                    }
+                    None => None,
+                };
+                self.write_local_var(loop_n_index);
+                // init counter to 0
+                self.process_card(&Card::ScalarInt(IntegerNode(0)))?;
+                self.write_local_var(loop_counter_index);
+
+                let block_begin = self.program.bytecode.len() as i32;
+                // loop condition
+                self.read_local_var(loop_counter_index);
+                self.read_local_var(loop_n_index);
+                self.process_card(&Card::Less)?;
+                // loop body
+                self.encode_if_then(Instruction::GotoIfFalse, |c| {
+                    if let Some(i_index) = i_index {
+                        c.read_local_var(loop_counter_index);
+                        c.write_local_var(i_index);
+                    }
+                    c.current_index.push_subindex(0);
+                    c.process_card(repeat)?;
+                    c.current_index.pop_subindex();
+                    // i = i + 1
+                    c.process_card(&Card::ScalarInt(IntegerNode(1)))?;
+                    c.read_local_var(loop_counter_index);
+                    c.process_card(&Card::Add)?;
+                    c.write_local_var(loop_counter_index);
+                    // return to the repeat instruction
+                    c.push_instruction(Instruction::Goto);
+                    write_to_vec(block_begin, &mut c.program.bytecode);
+                    Ok(())
+                })?;
+                self.scope_end();
             }
             Card::ReadVar(variable) => {
                 self.read_var_card(variable)?;
             }
             Card::SetVar(var) => {
-                let index = self.add_local(&var.0)?;
-                self.push_instruction(Instruction::SetLocalVar);
-                write_to_vec(index, &mut self.program.bytecode);
+                let index = match self.resolve_var(var.0.as_str())? {
+                    Some(i) => i as u32,
+                    None => self.add_local(&var.0)?,
+                };
+
+                self.write_local_var(index);
             }
             Card::SetGlobalVar(variable) => {
                 let next_var = &mut self.next_var;
@@ -587,9 +648,9 @@ impl<'a> Compiler<'a> {
     fn read_var_card(&mut self, variable: &VarNode) -> CompilationResult<()> {
         let scope = self.resolve_var(variable.0.as_str())?;
         match scope {
-            Some(scope) => {
+            Some(index) => {
                 //local
-                self.read_local_var(scope as u32);
+                self.read_local_var(index as u32);
             }
             None => {
                 // global
@@ -623,6 +684,11 @@ impl<'a> Compiler<'a> {
         write_to_vec(index, &mut self.program.bytecode);
     }
 
+    fn write_local_var(&mut self, index: u32) {
+        self.push_instruction(Instruction::SetLocalVar);
+        write_to_vec(index, &mut self.program.bytecode);
+    }
+
     fn validate_var_name(&self, name: &str) -> CompilationResult<()> {
         if name.is_empty() {
             return Err(self.error(CompilationErrorPayload::EmptyVariable));
