@@ -80,11 +80,20 @@ pub fn get_instruction_descriptions() -> Vec<SubProgramDescription> {
         get_desc(&Card::SetGlobalVar(Default::default())),
         get_desc(&Card::SetVar(Default::default())),
         get_desc(&Card::ReadVar(Default::default())),
-        get_desc(&Card::Repeat(Default::default())),
-        get_desc(&Card::While(Default::default())),
+        get_desc(&Card::Repeat {
+            i: None,
+            body: Default::default(),
+        }),
+        get_desc(&Card::While {
+            condition: Default::default(),
+            body: Default::default(),
+        }),
         get_desc(&Card::ForEach {
+            i: None,
+            k: None,
+            o: None,
             variable: Default::default(),
-            lane: Default::default(),
+            body: Default::default(),
         }),
     ]
 }
@@ -371,18 +380,18 @@ Order of parameters: Table, Property-Key, Value"#,
             []
         ),
 
-        Card::Repeat(_) => subprogram_description!(
+        Card::Repeat{..} => subprogram_description!(
             "Repeat",
-            "Repeat a lane the input number of times",
+            "Repeat the given card the input number of times",
             SubProgramType::Branch,
             [PropertyName::Number.to_str()],
             [],
             [PropertyName::Text.to_str()]
         ),
 
-        Card::While(_) => subprogram_description!(
+        Card::While{..} => subprogram_description!(
             "While",
-            "Repeat a lane until the lane's last value is 0",
+            "Repeat `body` until the condition is `false`",
             SubProgramType::Branch,
             [],
             [],
