@@ -7,7 +7,7 @@ pub use crate::procedures::*;
 pub use crate::traits::*;
 pub use crate::value::*;
 pub use crate::{
-    collections::key_map::Handle,
+    collections::handle_table::Handle,
     subprogram_description,
     vm::{runtime::FieldTable, Vm},
     InputString, StrPointer, SubProgramDescription, SubProgramType,
